@@ -139,6 +139,6 @@ class galleriffic_view(BrowserView):
             images = self.context.queryCatalog()
         else:
             ct_tool = getToolByName(self.context, "portal_catalog")
-            images = ct_tool(Type = 'Image', path = '/'.join(self.context.getPhysicalPath()))
+            images = ct_tool(Type = 'Image', path = '/'.join(self.context.getPhysicalPath()), sort_on="getObjPositionInParent")
         
         return images
\ No newline at end of file
